<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class ControleVendas extends CrudWithParameterBag  {
    
    protected $dataSourceName = 'vnd06700_relcontroledevendas';
    protected $parameterBagColumns = array('P_CDEMPRESA', 'P_CDFILIAL', 'P_CDLOJA', 'P_TCDLOJA', 'P_CDCAIXA', 'P_TCDCAIXA', 'P_CDSUBGRPROD', 'P_TCDSUBGRPROD', 'P_DTVENDAINI', 'P_DTVENDAFIN');
    protected $controleVendaService;
    protected $utilService;
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Services\ControleVendasService $service, Utilities\Util $utilService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->controleVendaService = $service;
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $request->getFilterCriteria()->getConditions(); 
        
        $dataSourceFilter = array();
        
        if(array_key_exists('CDEMPRESA', $conditions)) {
            $conditions['P_CDEMPRESA'] = $conditions['CDEMPRESA'];
            unset($conditions['CDEMPRESA']);
            
            $conditions['P_CDFILIAL'] = '_'.implode('_', $conditions['CDFILIAL']).'_';
            unset($conditions['CDFILIAL']);
            
            if( !array_key_exists('FILILOJA', $conditions) ) { 
                $conditions['P_TCDLOJA'] = 'T';    
                $conditions['P_CDLOJA'] = null;    
            } else { // FILIAL CONCATENADO COM LOJA
                $conditions['P_CDLOJA'] = '_'.implode('_', $conditions['FILILOJA'] ).'_';
                $conditions['P_TCDLOJA'] = 'F';
                unset($conditions['CDLOJA']);
                unset($conditions['FILILOJA']);
            }
            
            if( !array_key_exists('CDCAIXA', $conditions) ) { 
                $conditions['P_TCDCAIXA'] = 'T';    
                $conditions['P_CDCAIXA'] = null;    
            } else { // FILIAL CONCATENADO COM CAIXA
                $conditions['P_CDCAIXA'] = '_'.implode('_', $conditions['FILICAIXA'] ).'_';
                $conditions['P_TCDCAIXA'] = 'F';
                unset($conditions['CDCAIXA']);
                unset($conditions['FILICAIXA']);
            }
            
            if( !array_key_exists('NMSUBGRPROD', $conditions) ) {
                $conditions['P_TCDSUBGRPROD'] = 'T';    
                $conditions['P_CDSUBGRPROD'] = null;    
            } else {
                $conditions['P_CDSUBGRPROD'] = '_'.implode('_', $conditions['NMSUBGRPROD'] ).'_';
                $conditions['P_TCDSUBGRPROD'] = 'F';
                unset($conditions['NMSUBGRPROD']);
            }
            
            $conditions['P_DTVENDAINI'] = $conditions['DTMOVIMENTO'][0];
            $conditions['P_DTVENDAFIN'] = $conditions['DTMOVIMENTO'][1];
            unset($conditions['DTMOVIMENTO']);
            
            $aux['NMTIPOCUSTO'] = $conditions['NMTIPOCUSTO'];
            $aux['INFREL'] = $conditions['INFREL'];
            unset($conditions['NMTIPOCUSTO']);
            unset($conditions['INFREL']);
            unset($conditions['']);
            
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"=> "=",
                    "value"=> $value
                );
            }
            $filterCriteria = new FilterCriteria(
                $this->dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage(),
                $request->getFilterCriteria()->getPageSize()
            );
            $newRequest = new DTO\Request\Filter(
                $filterCriteria,
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            parent::find($newRequest, $response);
            $dataSet = $response->getDataSets()[0]->getRows();
            $response->addDataSet(new DataSet('vnd06700_relcontroledevendas', $this->controleVendaService->calculosRelatorio($conditions, $dataSet, $aux)));
            $dataSets = $response->getDataSets();
            array_shift($dataSets);
            $response->setDataSets($dataSets);
            
        }   
            
    }
}
